@@ -1,10 +1,12 @@
 __title__ = 'TwitterSearch'
-__version__ = '0.78.6'
+__version__ = '1.0.0'
 __author__ = 'Christian Koepp'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2013 Christian Koepp'
 
 from .TwitterSearch import TwitterSearch
+from .TwitterOrder import TwitterOrder
 from .TwitterSearchOrder import TwitterSearchOrder
+from .TwitterUserOrder import TwitterUserOrder
 from .TwitterSearchException import TwitterSearchException
 from .utils import py3k
